summaryrefslogtreecommitdiffstats
path: root/lib/kformula/matrixelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/matrixelement.h')
-rw-r--r--lib/kformula/matrixelement.h124
1 files changed, 62 insertions, 62 deletions
diff --git a/lib/kformula/matrixelement.h b/lib/kformula/matrixelement.h
index 5f7eec4d..ede10114 100644
--- a/lib/kformula/matrixelement.h
+++ b/lib/kformula/matrixelement.h
@@ -22,7 +22,7 @@
#ifndef MATRIXELEMENT_H
#define MATRIXELEMENT_H
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include "basicelement.h"
@@ -45,7 +45,7 @@ class MatrixElement : public BasicElement {
enum SideType { NoSide, LeftSide, RightSide, LeftOverlapSide, RightOverlapSide };
MatrixElement& operator=( const MatrixElement& ) { return *this; }
public:
- MatrixElement(uint rows = 1, uint columns = 1, BasicElement* parent = 0);
+ MatrixElement(uint rows = 1, uint columns = 1, BasicElement* tqparent = 0);
~MatrixElement();
MatrixElement( const MatrixElement& );
@@ -69,7 +69,7 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
// drawing
//
@@ -80,7 +80,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -88,19 +88,19 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
@@ -153,16 +153,16 @@ public:
virtual SequenceElement* getMainChild();
/**
- * Inserts all new children at the cursor position. Places the
+ * Inserts all new tqchildren at the cursor position. Places the
* cursor according to the direction.
*/
- //virtual void insert(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ //virtual void insert(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
- * Removes all selected children and returns them. Places the
- * cursor to where the children have been.
+ * Removes all selected tqchildren and returns them. Places the
+ * cursor to where the tqchildren have been.
*/
- //virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ //virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
* Moves the cursor to a normal place where new elements
@@ -184,18 +184,18 @@ public:
/**
* Returns wether the element has no more useful
- * children (except its main child) and should therefore
+ * tqchildren (except its main child) and should therefore
* be replaced by its main child's content.
*/
//virtual bool isSenseless();
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
uint getRows() const { return content.count(); }
uint getColumns() const { return content.getFirst()->count(); }
@@ -209,32 +209,32 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "MATRIX"; }
+ virtual TQString getTagName() const { return "MATRIX"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
- virtual QString getElementName() const { return "mtable"; }
- virtual void writeMathMLAttributes( QDomElement& element ) const;
- virtual void writeMathMLContent( QDomDocument& doc,
- QDomElement& element,
+ virtual TQString getElementName() const { return "mtable"; }
+ virtual void writeMathMLAttributes( TQDomElement& element ) const;
+ virtual void writeMathMLContent( TQDomDocument& doc,
+ TQDomElement& element,
bool oasisFormat ) const;
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
- virtual bool readAttributesFromMathMLDom( const QDomElement& element );
+ virtual bool readAttributesFromMathMLDom( const TQDomElement& element );
/**
* Reads our content from the MathML node. Sets the node to the next node
@@ -242,10 +242,10 @@ protected:
* (e. g. for fence operators).
* Returns the number of nodes processed or -1 if it failed.
*/
- virtual int readContentFromMathMLDom(QDomNode& node);
+ virtual int readContentFromMathMLDom(TQDomNode& node);
private:
- void writeMathMLAttributes( QDomElement& element );
+ void writeMathMLAttributes( TQDomElement& element );
MatrixSequenceElement* getElement(uint row, uint column)
{ return content.at(row)->at(column); }
@@ -262,26 +262,26 @@ private:
/**
* The elements we contain.
*/
- QPtrList< QPtrList< MatrixSequenceElement > > content;
+ TQPtrList< TQPtrList< MatrixSequenceElement > > content;
/**
* MathML Attributes. See Section 3.5.1.2
*/
int m_rowNumber;
VerticalAlign m_align;
- QValueList< VerticalAlign > m_rowAlign;
- QValueList< HorizontalAlign > m_columnAlign;
- QValueList< bool > m_alignmentScope;
- QValueList< SizeType > m_columnWidthType;
- QValueList< double > m_columnWidth;
+ TQValueList< VerticalAlign > m_rowAlign;
+ TQValueList< HorizontalAlign > m_columnAlign;
+ TQValueList< bool > m_tqalignmentScope;
+ TQValueList< SizeType > m_columnWidthType;
+ TQValueList< double > m_columnWidth;
SizeType m_widthType;
double m_width;
- QValueList< SizeType > m_rowSpacingType;
- QValueList< double > m_rowSpacing;
- QValueList< SizeType > m_columnSpacingType;
- QValueList< double > m_columnSpacing;
- QValueList< LineType > m_rowLines;
- QValueList< LineType > m_columnLines;
+ TQValueList< SizeType > m_rowSpacingType;
+ TQValueList< double > m_rowSpacing;
+ TQValueList< SizeType > m_columnSpacingType;
+ TQValueList< double > m_columnSpacing;
+ TQValueList< LineType > m_rowLines;
+ TQValueList< LineType > m_columnLines;
LineType m_frame;
SizeType m_frameHSpacingType;
double m_frameHSpacing;
@@ -316,7 +316,7 @@ public:
* The container this FormulaElement belongs to must not be 0,
* except you really know what you are doing.
*/
- MultilineElement( BasicElement* parent = 0 );
+ MultilineElement( BasicElement* tqparent = 0 );
~MultilineElement();
MultilineElement( const MultilineElement& );
@@ -337,7 +337,7 @@ public:
* Returns the element the point is in.
*/
BasicElement* goToPos( FormulaCursor* cursor, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
/**
* Sets the cursor inside this element to its start position.
@@ -375,7 +375,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -383,24 +383,24 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
- virtual void insert(FormulaCursor*, QPtrList<BasicElement>&, Direction);
- virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void insert(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
+ virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
virtual void normalize(FormulaCursor*, Direction);
@@ -414,13 +414,13 @@ public:
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
- virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false ) const ;
+ virtual void writeMathML( TQDomDocument& doc, TQDomNode& tqparent, bool oasisFormat = false ) const ;
protected:
@@ -429,25 +429,25 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "MULTILINE"; }
+ virtual TQString getTagName() const { return "MULTILINE"; }
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
private:
@@ -455,7 +455,7 @@ private:
/**
* The list of sequences. Each one is a line.
*/
- QPtrList< MultilineSequenceElement > content;
+ TQPtrList< MultilineSequenceElement > content;
};
@@ -88,19 +88,19 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/
@@ -383,24 +383,24 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/